--TEST--
various numeric types
--SKIPIF--
--FILE--
<?php
require_once dirname(__FILE__) . '/../common/config.php';

$numeric_types = array(
    array('TINYINT', -128, 127),
    array('TINYINT UNSIGNED', 0, 255),
    array('SMALLINT', -32768, 32768),
    array('SMALLINT UNSIGNED', 0, 65535),
    array('MEDIUMINT', -8388608, 8388607),
    array('MEDIUMINT UNSIGNED', 0, 16777215),
    array('INT', -2147483648, 2147483647),
    array('INT UNSIGNED', 0, 4294967295),
    array('BIGINT', -9223372036854775808, 9223372036854775807),
    array('BIGINT UNSIGNED', 0, 18446744073709551615),
    array('FLOAT', -32768, 32768),
    array('DOUBLE', -2147483648, 2147483647)
);

foreach ($numeric_types as $val)
{
    $type = $val[0];
    $minval = $val[1];
    $maxval = $val[2];

    $vals = array();
    array_push($vals, 0);
    array_push($vals, 1);
    array_push($vals, $maxval);

    if ($minval != 0)
    {
        array_push($vals, -1);
        array_push($vals, $minval);
    }

    $v1 = $minval;
    $v2 = $maxval;

    for ($i = 0; $i < 5; $i++)
    {
        $v1 /= 3;
        $v2 /= 3;

        $v1 = (int)$v1;
        $v2 = (int)$v2;

        if ($v1 != 0)
        {
            array_push($vals, $v1);
        }
        array_push($vals, $v2);
    }

    sort($vals);

    echo 'TYPE ', $type, PHP_EOL;

    test_one($type, $vals);

    echo PHP_EOL;
}

function test_one($type, $values = array())
{
    $mysql = get_mysql_connection();

    init_mysql_testdb($mysql);

    $table = 'hstesttbl';
    $sql = sprintf(
        'CREATE TABLE %s ( ' .
        'k ' . $type . ' PRIMARY KEY, ' .
        'v1 varchar(512), ' .
        'v2 ' . $type . ', ' .
        'index i1(v1), index i2(v2, v1)) ' .
        'Engine = myisam default charset = binary',
        mysql_real_escape_string($table));
    if (!mysql_query($sql, $mysql))
    {
        die(mysql_error());
    }

    $hs = new HandlerSocket(MYSQL_HOST, MYSQL_HANDLERSOCKET_PORT_WR);
    if (!($hs->openIndex(1, MYSQL_DBNAME, $table, '', 'k,v1,v2')))
    {
        die();
    }
    if (!($hs->openIndex(2, MYSQL_DBNAME, $table, 'i1', 'k,v1,v2')))
    {
        die();
    }
    if (!($hs->openIndex(3, MYSQL_DBNAME, $table, 'i2', 'k,v1,v2')))
    {
        die();
    }

    foreach ($values as $val)
    {
        $kstr = 's' . $val;

        $retval = $hs->executeSingle(1, '+', array($val, $kstr, $val), 0, 0);
        /*
        if ($retval === false)
        {
            echo $hs->getError(), PHP_EOL;
        }
        */
    }

    dump_table($mysql, $table);

    foreach ($values as $val)
    {
        $kstr = 's' . $val;

        $retval = $hs->executeSingle(1, '=', array($val), 1, 0);
        if ($retval)
        {
            $retval = array_shift($retval);
            echo 'PK[', $val, ']';
            for ($j = 0; $j < 3; $j++)
            {
                if (isset($retval[$j]))
                {
                    echo ' ', $retval[$j];
                }
            }
            echo PHP_EOL;
        }
        else
        {
            echo $hs->getError(), PHP_EOL;
        }

        $retval = $hs->executeSingle(2, '=', array($kstr), 1, 0);
        if ($retval)
        {
            $retval = array_shift($retval);
            echo 'I1[', $kstr, ']';
            for ($j = 0; $j < 3; $j++)
            {
                if (isset($retval[$j]))
                {
                    echo ' ', $retval[$j];
                }
            }
            echo PHP_EOL;
        }
        else
        {
            echo $hs->getError(), PHP_EOL;
        }

        $retval = $hs->executeSingle(3, '=', array($val, $kstr), 1, 0);
        if ($retval)
        {
            $retval = array_shift($retval);
            echo 'I2[', $val, ', ', $kstr, ']';
            for ($j = 0; $j < 3; $j++)
            {
                if (isset($retval[$j]))
                {
                    echo ' ', $retval[$j];
                }
            }
            echo PHP_EOL;
        }
        else
        {
            echo $hs->getError(), PHP_EOL;
        }

        $retval = $hs->executeSingle(3, '=', array($val), 1, 0);
        if ($retval)
        {
            $retval = array_shift($retval);
            echo 'I2p[', $val, ']';
            for ($j = 0; $j < 3; $j++)
            {
                if (isset($retval[$j]))
                {
                    echo ' ', $retval[$j];
                }
            }
            echo PHP_EOL;
        }
        else
        {
            echo $hs->getError(), PHP_EOL;
        }
    }

    mysql_close($mysql);
}

function dump_table($mysql, $table)
{
    echo 'DUMP_TABLE_BEGIN', PHP_EOL;
    $sql = 'SELECT k,v1,v2 FROM ' . $table . ' ORDER BY k';
    $result = mysql_query($sql, $mysql);
    if ($result)
    {
        while ($row = mysql_fetch_assoc($result))
        {
            echo $row['k'], ' ', $row['v1'], ' ', $row['v2'], PHP_EOL;
        }
    }
    mysql_free_result($result);
    echo 'DUMP_TABLE_END', PHP_EOL;
}

--EXPECT--
TYPE TINYINT
DUMP_TABLE_BEGIN
-128 s-128 -128
-42 s-42 -42
-14 s-14 -14
-4 s-4 -4
-1 s-1 -1
0 s0 0
1 s1 1
4 s4 4
14 s14 14
42 s42 42
127 s127 127
DUMP_TABLE_END
PK[-128] -128 s-128 -128
I1[s-128] -128 s-128 -128
I2[-128, s-128] -128 s-128 -128
I2p[-128] -128 s-128 -128
PK[-42] -42 s-42 -42
I1[s-42] -42 s-42 -42
I2[-42, s-42] -42 s-42 -42
I2p[-42] -42 s-42 -42
PK[-14] -14 s-14 -14
I1[s-14] -14 s-14 -14
I2[-14, s-14] -14 s-14 -14
I2p[-14] -14 s-14 -14
PK[-4] -4 s-4 -4
I1[s-4] -4 s-4 -4
I2[-4, s-4] -4 s-4 -4
I2p[-4] -4 s-4 -4
PK[-1] -1 s-1 -1
I1[s-1] -1 s-1 -1
I2[-1, s-1] -1 s-1 -1
I2p[-1] -1 s-1 -1
PK[-1] -1 s-1 -1
I1[s-1] -1 s-1 -1
I2[-1, s-1] -1 s-1 -1
I2p[-1] -1 s-1 -1
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[4] 4 s4 4
I1[s4] 4 s4 4
I2[4, s4] 4 s4 4
I2p[4] 4 s4 4
PK[14] 14 s14 14
I1[s14] 14 s14 14
I2[14, s14] 14 s14 14
I2p[14] 14 s14 14
PK[42] 42 s42 42
I1[s42] 42 s42 42
I2[42, s42] 42 s42 42
I2p[42] 42 s42 42
PK[127] 127 s127 127
I1[s127] 127 s127 127
I2[127, s127] 127 s127 127
I2p[127] 127 s127 127

TYPE TINYINT UNSIGNED
DUMP_TABLE_BEGIN
0 s0 0
1 s1 1
3 s3 3
9 s9 9
28 s28 28
85 s85 85
255 s255 255
DUMP_TABLE_END
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[3] 3 s3 3
I1[s3] 3 s3 3
I2[3, s3] 3 s3 3
I2p[3] 3 s3 3
PK[9] 9 s9 9
I1[s9] 9 s9 9
I2[9, s9] 9 s9 9
I2p[9] 9 s9 9
PK[28] 28 s28 28
I1[s28] 28 s28 28
I2[28, s28] 28 s28 28
I2p[28] 28 s28 28
PK[85] 85 s85 85
I1[s85] 85 s85 85
I2[85, s85] 85 s85 85
I2p[85] 85 s85 85
PK[255] 255 s255 255
I1[s255] 255 s255 255
I2[255, s255] 255 s255 255
I2p[255] 255 s255 255

TYPE SMALLINT
DUMP_TABLE_BEGIN
-32768 s-32768 -32768
-10922 s-10922 -10922
-3640 s-3640 -3640
-1213 s-1213 -1213
-404 s-404 -404
-134 s-134 -134
-1 s-1 -1
0 s0 0
1 s1 1
134 s134 134
404 s404 404
1213 s1213 1213
3640 s3640 3640
10922 s10922 10922
32767 s32768 32767
DUMP_TABLE_END
PK[-32768] -32768 s-32768 -32768
I1[s-32768] -32768 s-32768 -32768
I2[-32768, s-32768] -32768 s-32768 -32768
I2p[-32768] -32768 s-32768 -32768
PK[-10922] -10922 s-10922 -10922
I1[s-10922] -10922 s-10922 -10922
I2[-10922, s-10922] -10922 s-10922 -10922
I2p[-10922] -10922 s-10922 -10922
PK[-3640] -3640 s-3640 -3640
I1[s-3640] -3640 s-3640 -3640
I2[-3640, s-3640] -3640 s-3640 -3640
I2p[-3640] -3640 s-3640 -3640
PK[-1213] -1213 s-1213 -1213
I1[s-1213] -1213 s-1213 -1213
I2[-1213, s-1213] -1213 s-1213 -1213
I2p[-1213] -1213 s-1213 -1213
PK[-404] -404 s-404 -404
I1[s-404] -404 s-404 -404
I2[-404, s-404] -404 s-404 -404
I2p[-404] -404 s-404 -404
PK[-134] -134 s-134 -134
I1[s-134] -134 s-134 -134
I2[-134, s-134] -134 s-134 -134
I2p[-134] -134 s-134 -134
PK[-1] -1 s-1 -1
I1[s-1] -1 s-1 -1
I2[-1, s-1] -1 s-1 -1
I2p[-1] -1 s-1 -1
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[134] 134 s134 134
I1[s134] 134 s134 134
I2[134, s134] 134 s134 134
I2p[134] 134 s134 134
PK[404] 404 s404 404
I1[s404] 404 s404 404
I2[404, s404] 404 s404 404
I2p[404] 404 s404 404
PK[1213] 1213 s1213 1213
I1[s1213] 1213 s1213 1213
I2[1213, s1213] 1213 s1213 1213
I2p[1213] 1213 s1213 1213
PK[3640] 3640 s3640 3640
I1[s3640] 3640 s3640 3640
I2[3640, s3640] 3640 s3640 3640
I2p[3640] 3640 s3640 3640
PK[10922] 10922 s10922 10922
I1[s10922] 10922 s10922 10922
I2[10922, s10922] 10922 s10922 10922
I2p[10922] 10922 s10922 10922
PK[32768] 32767 s32768 32767
I1[s32768] 32767 s32768 32767
I2[32768, s32768] 32767 s32768 32767
I2p[32768] 32767 s32768 32767

TYPE SMALLINT UNSIGNED
DUMP_TABLE_BEGIN
0 s0 0
1 s1 1
269 s269 269
809 s809 809
2427 s2427 2427
7281 s7281 7281
21845 s21845 21845
65535 s65535 65535
DUMP_TABLE_END
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[269] 269 s269 269
I1[s269] 269 s269 269
I2[269, s269] 269 s269 269
I2p[269] 269 s269 269
PK[809] 809 s809 809
I1[s809] 809 s809 809
I2[809, s809] 809 s809 809
I2p[809] 809 s809 809
PK[2427] 2427 s2427 2427
I1[s2427] 2427 s2427 2427
I2[2427, s2427] 2427 s2427 2427
I2p[2427] 2427 s2427 2427
PK[7281] 7281 s7281 7281
I1[s7281] 7281 s7281 7281
I2[7281, s7281] 7281 s7281 7281
I2p[7281] 7281 s7281 7281
PK[21845] 21845 s21845 21845
I1[s21845] 21845 s21845 21845
I2[21845, s21845] 21845 s21845 21845
I2p[21845] 21845 s21845 21845
PK[65535] 65535 s65535 65535
I1[s65535] 65535 s65535 65535
I2[65535, s65535] 65535 s65535 65535
I2p[65535] 65535 s65535 65535

TYPE MEDIUMINT
DUMP_TABLE_BEGIN
-8388608 s-8388608 -8388608
-2796202 s-2796202 -2796202
-932067 s-932067 -932067
-310689 s-310689 -310689
-103563 s-103563 -103563
-34521 s-34521 -34521
-1 s-1 -1
0 s0 0
1 s1 1
34521 s34521 34521
103563 s103563 103563
310689 s310689 310689
932067 s932067 932067
2796202 s2796202 2796202
8388607 s8388607 8388607
DUMP_TABLE_END
PK[-8388608] -8388608 s-8388608 -8388608
I1[s-8388608] -8388608 s-8388608 -8388608
I2[-8388608, s-8388608] -8388608 s-8388608 -8388608
I2p[-8388608] -8388608 s-8388608 -8388608
PK[-2796202] -2796202 s-2796202 -2796202
I1[s-2796202] -2796202 s-2796202 -2796202
I2[-2796202, s-2796202] -2796202 s-2796202 -2796202
I2p[-2796202] -2796202 s-2796202 -2796202
PK[-932067] -932067 s-932067 -932067
I1[s-932067] -932067 s-932067 -932067
I2[-932067, s-932067] -932067 s-932067 -932067
I2p[-932067] -932067 s-932067 -932067
PK[-310689] -310689 s-310689 -310689
I1[s-310689] -310689 s-310689 -310689
I2[-310689, s-310689] -310689 s-310689 -310689
I2p[-310689] -310689 s-310689 -310689
PK[-103563] -103563 s-103563 -103563
I1[s-103563] -103563 s-103563 -103563
I2[-103563, s-103563] -103563 s-103563 -103563
I2p[-103563] -103563 s-103563 -103563
PK[-34521] -34521 s-34521 -34521
I1[s-34521] -34521 s-34521 -34521
I2[-34521, s-34521] -34521 s-34521 -34521
I2p[-34521] -34521 s-34521 -34521
PK[-1] -1 s-1 -1
I1[s-1] -1 s-1 -1
I2[-1, s-1] -1 s-1 -1
I2p[-1] -1 s-1 -1
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[34521] 34521 s34521 34521
I1[s34521] 34521 s34521 34521
I2[34521, s34521] 34521 s34521 34521
I2p[34521] 34521 s34521 34521
PK[103563] 103563 s103563 103563
I1[s103563] 103563 s103563 103563
I2[103563, s103563] 103563 s103563 103563
I2p[103563] 103563 s103563 103563
PK[310689] 310689 s310689 310689
I1[s310689] 310689 s310689 310689
I2[310689, s310689] 310689 s310689 310689
I2p[310689] 310689 s310689 310689
PK[932067] 932067 s932067 932067
I1[s932067] 932067 s932067 932067
I2[932067, s932067] 932067 s932067 932067
I2p[932067] 932067 s932067 932067
PK[2796202] 2796202 s2796202 2796202
I1[s2796202] 2796202 s2796202 2796202
I2[2796202, s2796202] 2796202 s2796202 2796202
I2p[2796202] 2796202 s2796202 2796202
PK[8388607] 8388607 s8388607 8388607
I1[s8388607] 8388607 s8388607 8388607
I2[8388607, s8388607] 8388607 s8388607 8388607
I2p[8388607] 8388607 s8388607 8388607

TYPE MEDIUMINT UNSIGNED
DUMP_TABLE_BEGIN
0 s0 0
1 s1 1
69042 s69042 69042
207126 s207126 207126
621378 s621378 621378
1864135 s1864135 1864135
5592405 s5592405 5592405
16777215 s16777215 16777215
DUMP_TABLE_END
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[69042] 69042 s69042 69042
I1[s69042] 69042 s69042 69042
I2[69042, s69042] 69042 s69042 69042
I2p[69042] 69042 s69042 69042
PK[207126] 207126 s207126 207126
I1[s207126] 207126 s207126 207126
I2[207126, s207126] 207126 s207126 207126
I2p[207126] 207126 s207126 207126
PK[621378] 621378 s621378 621378
I1[s621378] 621378 s621378 621378
I2[621378, s621378] 621378 s621378 621378
I2p[621378] 621378 s621378 621378
PK[1864135] 1864135 s1864135 1864135
I1[s1864135] 1864135 s1864135 1864135
I2[1864135, s1864135] 1864135 s1864135 1864135
I2p[1864135] 1864135 s1864135 1864135
PK[5592405] 5592405 s5592405 5592405
I1[s5592405] 5592405 s5592405 5592405
I2[5592405, s5592405] 5592405 s5592405 5592405
I2p[5592405] 5592405 s5592405 5592405
PK[16777215] 16777215 s16777215 16777215
I1[s16777215] 16777215 s16777215 16777215
I2[16777215, s16777215] 16777215 s16777215 16777215
I2p[16777215] 16777215 s16777215 16777215

TYPE INT
DUMP_TABLE_BEGIN
-2147483648 s-2147483648 -2147483648
-715827882 s-715827882 -715827882
-238609294 s-238609294 -238609294
-79536431 s-79536431 -79536431
-26512143 s-26512143 -26512143
-8837381 s-8837381 -8837381
-1 s-1 -1
0 s0 0
1 s1 1
8837381 s8837381 8837381
26512143 s26512143 26512143
79536431 s79536431 79536431
238609294 s238609294 238609294
715827882 s715827882 715827882
2147483647 s2147483647 2147483647
DUMP_TABLE_END
PK[-2147483648] -2147483648 s-2147483648 -2147483648
I1[s-2147483648] -2147483648 s-2147483648 -2147483648
I2[-2147483648, s-2147483648] -2147483648 s-2147483648 -2147483648
I2p[-2147483648] -2147483648 s-2147483648 -2147483648
PK[-715827882] -715827882 s-715827882 -715827882
I1[s-715827882] -715827882 s-715827882 -715827882
I2[-715827882, s-715827882] -715827882 s-715827882 -715827882
I2p[-715827882] -715827882 s-715827882 -715827882
PK[-238609294] -238609294 s-238609294 -238609294
I1[s-238609294] -238609294 s-238609294 -238609294
I2[-238609294, s-238609294] -238609294 s-238609294 -238609294
I2p[-238609294] -238609294 s-238609294 -238609294
PK[-79536431] -79536431 s-79536431 -79536431
I1[s-79536431] -79536431 s-79536431 -79536431
I2[-79536431, s-79536431] -79536431 s-79536431 -79536431
I2p[-79536431] -79536431 s-79536431 -79536431
PK[-26512143] -26512143 s-26512143 -26512143
I1[s-26512143] -26512143 s-26512143 -26512143
I2[-26512143, s-26512143] -26512143 s-26512143 -26512143
I2p[-26512143] -26512143 s-26512143 -26512143
PK[-8837381] -8837381 s-8837381 -8837381
I1[s-8837381] -8837381 s-8837381 -8837381
I2[-8837381, s-8837381] -8837381 s-8837381 -8837381
I2p[-8837381] -8837381 s-8837381 -8837381
PK[-1] -1 s-1 -1
I1[s-1] -1 s-1 -1
I2[-1, s-1] -1 s-1 -1
I2p[-1] -1 s-1 -1
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[8837381] 8837381 s8837381 8837381
I1[s8837381] 8837381 s8837381 8837381
I2[8837381, s8837381] 8837381 s8837381 8837381
I2p[8837381] 8837381 s8837381 8837381
PK[26512143] 26512143 s26512143 26512143
I1[s26512143] 26512143 s26512143 26512143
I2[26512143, s26512143] 26512143 s26512143 26512143
I2p[26512143] 26512143 s26512143 26512143
PK[79536431] 79536431 s79536431 79536431
I1[s79536431] 79536431 s79536431 79536431
I2[79536431, s79536431] 79536431 s79536431 79536431
I2p[79536431] 79536431 s79536431 79536431
PK[238609294] 238609294 s238609294 238609294
I1[s238609294] 238609294 s238609294 238609294
I2[238609294, s238609294] 238609294 s238609294 238609294
I2p[238609294] 238609294 s238609294 238609294
PK[715827882] 715827882 s715827882 715827882
I1[s715827882] 715827882 s715827882 715827882
I2[715827882, s715827882] 715827882 s715827882 715827882
I2p[715827882] 715827882 s715827882 715827882
PK[2147483647] 2147483647 s2147483647 2147483647
I1[s2147483647] 2147483647 s2147483647 2147483647
I2[2147483647, s2147483647] 2147483647 s2147483647 2147483647
I2p[2147483647] 2147483647 s2147483647 2147483647

TYPE INT UNSIGNED
DUMP_TABLE_BEGIN
0 s0 0
1 s1 1
17674762 s17674762 17674762
53024287 s53024287 53024287
159072862 s159072862 159072862
477218588 s477218588 477218588
1431655765 s1431655765 1431655765
4294967295 s4294967295 4294967295
DUMP_TABLE_END
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[17674762] 17674762 s17674762 17674762
I1[s17674762] 17674762 s17674762 17674762
I2[17674762, s17674762] 17674762 s17674762 17674762
I2p[17674762] 17674762 s17674762 17674762
PK[53024287] 53024287 s53024287 53024287
I1[s53024287] 53024287 s53024287 53024287
I2[53024287, s53024287] 53024287 s53024287 53024287
I2p[53024287] 53024287 s53024287 53024287
PK[159072862] 159072862 s159072862 159072862
I1[s159072862] 159072862 s159072862 159072862
I2[159072862, s159072862] 159072862 s159072862 159072862
I2p[159072862] 159072862 s159072862 159072862
PK[477218588] 477218588 s477218588 477218588
I1[s477218588] 477218588 s477218588 477218588
I2[477218588, s477218588] 477218588 s477218588 477218588
I2p[477218588] 477218588 s477218588 477218588
PK[1431655765] 1431655765 s1431655765 1431655765
I1[s1431655765] 1431655765 s1431655765 1431655765
I2[1431655765, s1431655765] 1431655765 s1431655765 1431655765
I2p[1431655765] 1431655765 s1431655765 1431655765
PK[4294967295] 4294967295 s4294967295 4294967295
I1[s4294967295] 4294967295 s4294967295 4294967295
I2[4294967295, s4294967295] 4294967295 s4294967295 4294967295
I2p[4294967295] 4294967295 s4294967295 4294967295

TYPE BIGINT
DUMP_TABLE_BEGIN
-9223372036854775808 s-9.2233720368548E+18 -9223372036854775808
-3074457345618258432 s-3074457345618258432 -3074457345618258432
-1024819115206086144 s-1024819115206086144 -1024819115206086144
-341606371735362048 s-341606371735362048 -341606371735362048
-113868790578454016 s-113868790578454016 -113868790578454016
-37956263526151336 s-37956263526151336 -37956263526151336
-1 s-1 -1
0 s0 0
1 s1 1
37956263526151336 s37956263526151336 37956263526151336
113868790578454016 s113868790578454016 113868790578454016
341606371735362048 s341606371735362048 341606371735362048
1024819115206086144 s1024819115206086144 1024819115206086144
3074457345618258432 s3074457345618258432 3074457345618258432
9223372036854775807 s9223372036854775807 9223372036854775807
DUMP_TABLE_END
PK[-9.2233720368548E+18] -9223372036854775808 s-9.2233720368548E+18 -9223372036854775808
I1[s-9.2233720368548E+18] -9223372036854775808 s-9.2233720368548E+18 -9223372036854775808
I2[-9.2233720368548E+18, s-9.2233720368548E+18] -9223372036854775808 s-9.2233720368548E+18 -9223372036854775808
I2p[-9.2233720368548E+18] -9223372036854775808 s-9.2233720368548E+18 -9223372036854775808
PK[-3074457345618258432] -3074457345618258432 s-3074457345618258432 -3074457345618258432
I1[s-3074457345618258432] -3074457345618258432 s-3074457345618258432 -3074457345618258432
I2[-3074457345618258432, s-3074457345618258432] -3074457345618258432 s-3074457345618258432 -3074457345618258432
I2p[-3074457345618258432] -3074457345618258432 s-3074457345618258432 -3074457345618258432
PK[-1024819115206086144] -1024819115206086144 s-1024819115206086144 -1024819115206086144
I1[s-1024819115206086144] -1024819115206086144 s-1024819115206086144 -1024819115206086144
I2[-1024819115206086144, s-1024819115206086144] -1024819115206086144 s-1024819115206086144 -1024819115206086144
I2p[-1024819115206086144] -1024819115206086144 s-1024819115206086144 -1024819115206086144
PK[-341606371735362048] -341606371735362048 s-341606371735362048 -341606371735362048
I1[s-341606371735362048] -341606371735362048 s-341606371735362048 -341606371735362048
I2[-341606371735362048, s-341606371735362048] -341606371735362048 s-341606371735362048 -341606371735362048
I2p[-341606371735362048] -341606371735362048 s-341606371735362048 -341606371735362048
PK[-113868790578454016] -113868790578454016 s-113868790578454016 -113868790578454016
I1[s-113868790578454016] -113868790578454016 s-113868790578454016 -113868790578454016
I2[-113868790578454016, s-113868790578454016] -113868790578454016 s-113868790578454016 -113868790578454016
I2p[-113868790578454016] -113868790578454016 s-113868790578454016 -113868790578454016
PK[-37956263526151336] -37956263526151336 s-37956263526151336 -37956263526151336
I1[s-37956263526151336] -37956263526151336 s-37956263526151336 -37956263526151336
I2[-37956263526151336, s-37956263526151336] -37956263526151336 s-37956263526151336 -37956263526151336
I2p[-37956263526151336] -37956263526151336 s-37956263526151336 -37956263526151336
PK[-1] -1 s-1 -1
I1[s-1] -1 s-1 -1
I2[-1, s-1] -1 s-1 -1
I2p[-1] -1 s-1 -1
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[37956263526151336] 37956263526151336 s37956263526151336 37956263526151336
I1[s37956263526151336] 37956263526151336 s37956263526151336 37956263526151336
I2[37956263526151336, s37956263526151336] 37956263526151336 s37956263526151336 37956263526151336
I2p[37956263526151336] 37956263526151336 s37956263526151336 37956263526151336
PK[113868790578454016] 113868790578454016 s113868790578454016 113868790578454016
I1[s113868790578454016] 113868790578454016 s113868790578454016 113868790578454016
I2[113868790578454016, s113868790578454016] 113868790578454016 s113868790578454016 113868790578454016
I2p[113868790578454016] 113868790578454016 s113868790578454016 113868790578454016
PK[341606371735362048] 341606371735362048 s341606371735362048 341606371735362048
I1[s341606371735362048] 341606371735362048 s341606371735362048 341606371735362048
I2[341606371735362048, s341606371735362048] 341606371735362048 s341606371735362048 341606371735362048
I2p[341606371735362048] 341606371735362048 s341606371735362048 341606371735362048
PK[1024819115206086144] 1024819115206086144 s1024819115206086144 1024819115206086144
I1[s1024819115206086144] 1024819115206086144 s1024819115206086144 1024819115206086144
I2[1024819115206086144, s1024819115206086144] 1024819115206086144 s1024819115206086144 1024819115206086144
I2p[1024819115206086144] 1024819115206086144 s1024819115206086144 1024819115206086144
PK[3074457345618258432] 3074457345618258432 s3074457345618258432 3074457345618258432
I1[s3074457345618258432] 3074457345618258432 s3074457345618258432 3074457345618258432
I2[3074457345618258432, s3074457345618258432] 3074457345618258432 s3074457345618258432 3074457345618258432
I2p[3074457345618258432] 3074457345618258432 s3074457345618258432 3074457345618258432
PK[9223372036854775807] 9223372036854775807 s9223372036854775807 9223372036854775807
I1[s9223372036854775807] 9223372036854775807 s9223372036854775807 9223372036854775807
I2[9223372036854775807, s9223372036854775807] 9223372036854775807 s9223372036854775807 9223372036854775807
I2p[9223372036854775807] 9223372036854775807 s9223372036854775807 9223372036854775807

TYPE BIGINT UNSIGNED
DUMP_TABLE_BEGIN
0 s0 0
1 s1 1
75912527052302672 s75912527052302672 75912527052302672
227737581156908032 s227737581156908032 227737581156908032
683212743470724096 s683212743470724096 683212743470724096
2049638230412172288 s2049638230412172288 2049638230412172288
6148914691236516864 s6148914691236516864 6148914691236516864
18446744073709551615 s1.844674407371E+19 18446744073709551615
DUMP_TABLE_END
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[75912527052302672] 75912527052302672 s75912527052302672 75912527052302672
I1[s75912527052302672] 75912527052302672 s75912527052302672 75912527052302672
I2[75912527052302672, s75912527052302672] 75912527052302672 s75912527052302672 75912527052302672
I2p[75912527052302672] 75912527052302672 s75912527052302672 75912527052302672
PK[227737581156908032] 227737581156908032 s227737581156908032 227737581156908032
I1[s227737581156908032] 227737581156908032 s227737581156908032 227737581156908032
I2[227737581156908032, s227737581156908032] 227737581156908032 s227737581156908032 227737581156908032
I2p[227737581156908032] 227737581156908032 s227737581156908032 227737581156908032
PK[683212743470724096] 683212743470724096 s683212743470724096 683212743470724096
I1[s683212743470724096] 683212743470724096 s683212743470724096 683212743470724096
I2[683212743470724096, s683212743470724096] 683212743470724096 s683212743470724096 683212743470724096
I2p[683212743470724096] 683212743470724096 s683212743470724096 683212743470724096
PK[2049638230412172288] 2049638230412172288 s2049638230412172288 2049638230412172288
I1[s2049638230412172288] 2049638230412172288 s2049638230412172288 2049638230412172288
I2[2049638230412172288, s2049638230412172288] 2049638230412172288 s2049638230412172288 2049638230412172288
I2p[2049638230412172288] 2049638230412172288 s2049638230412172288 2049638230412172288
PK[6148914691236516864] 6148914691236516864 s6148914691236516864 6148914691236516864
I1[s6148914691236516864] 6148914691236516864 s6148914691236516864 6148914691236516864
I2[6148914691236516864, s6148914691236516864] 6148914691236516864 s6148914691236516864 6148914691236516864
I2p[6148914691236516864] 6148914691236516864 s6148914691236516864 6148914691236516864
PK[1.844674407371E+19] 18446744073709551615 s1.844674407371E+19 18446744073709551615
I1[s1.844674407371E+19] 18446744073709551615 s1.844674407371E+19 18446744073709551615
I2[1.844674407371E+19, s1.844674407371E+19] 18446744073709551615 s1.844674407371E+19 18446744073709551615
I2p[1.844674407371E+19] 18446744073709551615 s1.844674407371E+19 18446744073709551615

TYPE FLOAT
DUMP_TABLE_BEGIN
-32768 s-32768 -32768
-10922 s-10922 -10922
-3640 s-3640 -3640
-1213 s-1213 -1213
-404 s-404 -404
-134 s-134 -134
-1 s-1 -1
0 s0 0
1 s1 1
134 s134 134
404 s404 404
1213 s1213 1213
3640 s3640 3640
10922 s10922 10922
32768 s32768 32768
DUMP_TABLE_END
PK[-32768] -32768 s-32768 -32768
I1[s-32768] -32768 s-32768 -32768
I2[-32768, s-32768] -32768 s-32768 -32768
I2p[-32768] -32768 s-32768 -32768
PK[-10922] -10922 s-10922 -10922
I1[s-10922] -10922 s-10922 -10922
I2[-10922, s-10922] -10922 s-10922 -10922
I2p[-10922] -10922 s-10922 -10922
PK[-3640] -3640 s-3640 -3640
I1[s-3640] -3640 s-3640 -3640
I2[-3640, s-3640] -3640 s-3640 -3640
I2p[-3640] -3640 s-3640 -3640
PK[-1213] -1213 s-1213 -1213
I1[s-1213] -1213 s-1213 -1213
I2[-1213, s-1213] -1213 s-1213 -1213
I2p[-1213] -1213 s-1213 -1213
PK[-404] -404 s-404 -404
I1[s-404] -404 s-404 -404
I2[-404, s-404] -404 s-404 -404
I2p[-404] -404 s-404 -404
PK[-134] -134 s-134 -134
I1[s-134] -134 s-134 -134
I2[-134, s-134] -134 s-134 -134
I2p[-134] -134 s-134 -134
PK[-1] -1 s-1 -1
I1[s-1] -1 s-1 -1
I2[-1, s-1] -1 s-1 -1
I2p[-1] -1 s-1 -1
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[134] 134 s134 134
I1[s134] 134 s134 134
I2[134, s134] 134 s134 134
I2p[134] 134 s134 134
PK[404] 404 s404 404
I1[s404] 404 s404 404
I2[404, s404] 404 s404 404
I2p[404] 404 s404 404
PK[1213] 1213 s1213 1213
I1[s1213] 1213 s1213 1213
I2[1213, s1213] 1213 s1213 1213
I2p[1213] 1213 s1213 1213
PK[3640] 3640 s3640 3640
I1[s3640] 3640 s3640 3640
I2[3640, s3640] 3640 s3640 3640
I2p[3640] 3640 s3640 3640
PK[10922] 10922 s10922 10922
I1[s10922] 10922 s10922 10922
I2[10922, s10922] 10922 s10922 10922
I2p[10922] 10922 s10922 10922
PK[32768] 32768 s32768 32768
I1[s32768] 32768 s32768 32768
I2[32768, s32768] 32768 s32768 32768
I2p[32768] 32768 s32768 32768

TYPE DOUBLE
DUMP_TABLE_BEGIN
-2147483648 s-2147483648 -2147483648
-715827882 s-715827882 -715827882
-238609294 s-238609294 -238609294
-79536431 s-79536431 -79536431
-26512143 s-26512143 -26512143
-8837381 s-8837381 -8837381
-1 s-1 -1
0 s0 0
1 s1 1
8837381 s8837381 8837381
26512143 s26512143 26512143
79536431 s79536431 79536431
238609294 s238609294 238609294
715827882 s715827882 715827882
2147483647 s2147483647 2147483647
DUMP_TABLE_END
PK[-2147483648] -2147483648 s-2147483648 -2147483648
I1[s-2147483648] -2147483648 s-2147483648 -2147483648
I2[-2147483648, s-2147483648] -2147483648 s-2147483648 -2147483648
I2p[-2147483648] -2147483648 s-2147483648 -2147483648
PK[-715827882] -715827882 s-715827882 -715827882
I1[s-715827882] -715827882 s-715827882 -715827882
I2[-715827882, s-715827882] -715827882 s-715827882 -715827882
I2p[-715827882] -715827882 s-715827882 -715827882
PK[-238609294] -238609294 s-238609294 -238609294
I1[s-238609294] -238609294 s-238609294 -238609294
I2[-238609294, s-238609294] -238609294 s-238609294 -238609294
I2p[-238609294] -238609294 s-238609294 -238609294
PK[-79536431] -79536431 s-79536431 -79536431
I1[s-79536431] -79536431 s-79536431 -79536431
I2[-79536431, s-79536431] -79536431 s-79536431 -79536431
I2p[-79536431] -79536431 s-79536431 -79536431
PK[-26512143] -26512143 s-26512143 -26512143
I1[s-26512143] -26512143 s-26512143 -26512143
I2[-26512143, s-26512143] -26512143 s-26512143 -26512143
I2p[-26512143] -26512143 s-26512143 -26512143
PK[-8837381] -8837381 s-8837381 -8837381
I1[s-8837381] -8837381 s-8837381 -8837381
I2[-8837381, s-8837381] -8837381 s-8837381 -8837381
I2p[-8837381] -8837381 s-8837381 -8837381
PK[-1] -1 s-1 -1
I1[s-1] -1 s-1 -1
I2[-1, s-1] -1 s-1 -1
I2p[-1] -1 s-1 -1
PK[0] 0 s0 0
I1[s0] 0 s0 0
I2[0, s0] 0 s0 0
I2p[0] 0 s0 0
PK[1] 1 s1 1
I1[s1] 1 s1 1
I2[1, s1] 1 s1 1
I2p[1] 1 s1 1
PK[8837381] 8837381 s8837381 8837381
I1[s8837381] 8837381 s8837381 8837381
I2[8837381, s8837381] 8837381 s8837381 8837381
I2p[8837381] 8837381 s8837381 8837381
PK[26512143] 26512143 s26512143 26512143
I1[s26512143] 26512143 s26512143 26512143
I2[26512143, s26512143] 26512143 s26512143 26512143
I2p[26512143] 26512143 s26512143 26512143
PK[79536431] 79536431 s79536431 79536431
I1[s79536431] 79536431 s79536431 79536431
I2[79536431, s79536431] 79536431 s79536431 79536431
I2p[79536431] 79536431 s79536431 79536431
PK[238609294] 238609294 s238609294 238609294
I1[s238609294] 238609294 s238609294 238609294
I2[238609294, s238609294] 238609294 s238609294 238609294
I2p[238609294] 238609294 s238609294 238609294
PK[715827882] 715827882 s715827882 715827882
I1[s715827882] 715827882 s715827882 715827882
I2[715827882, s715827882] 715827882 s715827882 715827882
I2p[715827882] 715827882 s715827882 715827882
PK[2147483647] 2147483647 s2147483647 2147483647
I1[s2147483647] 2147483647 s2147483647 2147483647
I2[2147483647, s2147483647] 2147483647 s2147483647 2147483647
I2p[2147483647] 2147483647 s2147483647 2147483647

